@@ -1,11 +1,8 @@
 from django.core.exceptions import PermissionDenied
-from netbox.views           import generic
 from utilities.permissions  import resolve_permission
 
 
-#
-# Bulk view mixins.
-#
+# Bulk view mixin.
 class BulkCheckView:
     def post(self, request, *args, **kwargs):
         perm = self.get_required_permission()
@@ -26,21 +23,7 @@ class BulkCheckView:
         return super().post(request, *args, **kwargs)
 
 
-class BulkDeleteView(BulkCheckView, generic.BulkDeleteView):
-    pass
-
-
-class BulkEditView(BulkCheckView, generic.BulkEditView):
-    pass
-
-
-class BulkRenameView(BulkCheckView, generic.BulkRenameView):
-    pass
-
-
-#
-# Object view mixins.
-#
+# Object view mixin.
 class ObjectCheckView:
     def get(self, request, *args, **kwargs):
         obj  = self.get_object(kwargs)
@@ -50,11 +33,3 @@ class ObjectCheckView:
             raise PermissionDenied('%s %s' % (resolve_permission(perm)[1], obj))
 
         return super().get(request, *args, **kwargs)
-
-
-class ObjectDeleteView(ObjectCheckView, generic.ObjectDeleteView):
-    pass
-
-
-class ObjectEditView(ObjectCheckView, generic.ObjectEditView):
-    pass
